import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:apimodule/api/config/endpoint.dart';
import 'package:apimodule/api/config/apisettings.dart';
import 'package:apimodule/model/request/absent_request.dart';
import 'package:apimodule/model/request/global_request.dart';
import 'package:apimodule/model/response/absent_response.dart';
import 'package:apimodule/model/response/global_response.dart';
import 'package:apimodule/model/response/log_absent_response.dart';

class AbsentService {
  static Future<dynamic> fetchAbsentMasukLocation(AbsentRequest request) async {
    var absentRequest = new Map<String, dynamic>();
    absentRequest['nip'] = request.nip;
    absentRequest['lat'] = request.lat;
    absentRequest['long'] = request.long;
    absentRequest['device_id'] = request.deviceId;
    absentRequest['is_mocked'] = request.isMocked.toString();

    try {
      final response = await http.post(
        EndpointSimpersaa.absenMasuk,
        headers: null,
        body: absentRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return AbsentResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchAbsentKeluarLocation(
      AbsentRequest request) async {
    var absentRequest = new Map<String, dynamic>();
    absentRequest['nip'] = request.nip;
    absentRequest['lat'] = request.lat;
    absentRequest['long'] = request.long;
    absentRequest['device_id'] = request.deviceId;
    absentRequest['is_mocked'] = request.isMocked.toString();

    try {
      final response = await http.post(
        EndpointSimpersaa.absenKeluar,
        headers: null,
        body: absentRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return AbsentResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchIzin(AbsentRequest request) async {
    var absentRequest = new Map<String, dynamic>();
    absentRequest['nip'] = request.nip;
    absentRequest['lat'] = request.lat;
    absentRequest['long'] = request.long;
    absentRequest['device_id'] = request.deviceId;
    absentRequest['is_mocked'] = request.isMocked.toString();
    absentRequest['status'] = request.status;

    try {
      final response = await http.post(
        EndpointSimpersaa.izin,
        headers: null,
        body: absentRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return AbsentResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchAbsentQR(AbsentRequest request) async {
    var absentRequest = new Map<String, dynamic>();
    absentRequest['nip'] = request.nip;
    absentRequest['device_id'] = request.deviceId;

    try {
      final response = await http.post(
        EndpointSimpersaa.absenQR,
        headers: null,
        body: absentRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return AbsentResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchLogAbsent(GlobalRequest request) async {
    var logAbsentRequest = new Map<String, dynamic>();
    logAbsentRequest['nik'] = request.nipNik;
    try {
      final response = await http.post(
        EndpointSimpersaa.logAbsent,
        headers: null,
        body: logAbsentRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return LogAbsentResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }
}
