import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:apimodule/api/config/endpoint.dart';
import 'package:apimodule/api/config/apisettings.dart';
import 'package:apimodule/model/request/approval_cuti_request.dart';
import 'package:apimodule/model/request/global_request.dart';
import 'package:apimodule/model/request/pengajuan_cuti_request.dart';
import 'package:apimodule/model/response/global_response.dart';
import 'package:apimodule/model/response/initial_cuti_response.dart';
import 'package:apimodule/model/response/need_approval_response.dart';
import 'package:apimodule/model/response/pengajuan_response.dart';
import 'package:apimodule/model/response/riwayat_cuti_response.dart';

class CutiService {
  static Future<dynamic> initialCuti(GlobalRequest request) async {
    var globalRequest = new Map<String, dynamic>();
    globalRequest['id_nip_nrp'] = request.nipNik;

    try {
      final response = await http.post(
        EndpointSimpersaa.initialCuti,
        headers: null,
        body: globalRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return InitialCutiResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> pengajuanCuti(PengajuanCutiRequest request) async {
    var pengajuanCutiRequest = new Map<String, dynamic>();
    pengajuanCutiRequest['id_nip_nrp'] = request.idNipNrp;
    pengajuanCutiRequest['alasan'] = request.alasan;
    pengajuanCutiRequest['catatan_cuti'] = request.catatanCuti;
    pengajuanCutiRequest['tanggal_mulai_cuti'] = request.tanggalMulaiCuti;
    pengajuanCutiRequest['tanggal_terakhir_cuti'] = request.tanggalTerakhirCuti;
    pengajuanCutiRequest['lama_waktu_cuti'] = request.lamaWaktuCuti;
    pengajuanCutiRequest['lama_cuti_satuan'] = request.lamaCutiSatuan;
    pengajuanCutiRequest['jenis_cuti'] = request.jenisCuti;
    pengajuanCutiRequest['alamat_selama_cuti'] = request.alamatSelamaCuti;
    pengajuanCutiRequest['no_hp_selama_cuti'] = request.noHpSelamaCuti;
    pengajuanCutiRequest['id_nip_nrp_atasan'] = request.idNipNrpAtasan;
    pengajuanCutiRequest['id_nip_nrp_pejabat'] = request.idNipNrpPejabat;
    pengajuanCutiRequest['atasan_langsung'] = request.atasanLangsung;
    pengajuanCutiRequest['pejabat_pemberi_cuti'] = request.pejabatPemberiCuti;
    pengajuanCutiRequest['jabatan'] = request.jabatan;
    pengajuanCutiRequest['masa_kerja'] = request.masaKerja;

    try {
      final response = await http.post(
        EndpointSimpersaa.pengajuan,
        headers: null,
        body: pengajuanCutiRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return PengajuanResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> riwayatPengajuanCuti(GlobalRequest request) async {
    var globalRequest = new Map<String, dynamic>();
    globalRequest['id_nip_nrp'] = request.nipNik;

    try {
      final response = await http.post(
        EndpointSimpersaa.riwayatPengajuan,
        headers: null,
        body: globalRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return RiwayatCutiResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> needApproval(GlobalRequest request) async {
    var globalRequest = new Map<String, dynamic>();
    globalRequest['id_nip_nrp'] = request.nipNik;

    try {
      final response = await http.post(
        EndpointSimpersaa.needApproval,
        headers: null,
        body: globalRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return NeedApprovalResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> approval(ApprovalCutiRequest request) async {
    var approvalRequest = new Map<String, dynamic>();
    approvalRequest['id_nip_nrp'] = request.idNipNrp;
    approvalRequest['id_pengajuan'] = request.idPengajuan;
    approvalRequest['approval'] = request.approval;
    approvalRequest['perubahan'] = request.perubahan;
    approvalRequest['penangguhan'] = request.penangguhan;

    try {
      final response = await http.post(
        EndpointSimpersaa.approval,
        headers: null,
        body: approvalRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return PengajuanResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }
}
