import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:apimodule/api/config/endpoint.dart';
import 'package:apimodule/api/config/apisettings.dart';
import 'package:apimodule/model/response/global_response.dart';
import 'package:apimodule/model/response/screening_response.dart';

class ScreeningService {
  static Future<dynamic> getScreeningQuestion() async {
    final response =
        await http.get(EndpointSimpersaa.keriteriaVaksin, headers: null);

    try {
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return ScreeningResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> postScreeningQuestion(ScreeningResults request) async {
    final response = await http.post(
      EndpointSimpersaa.saveKeriteria,
      headers: APiSettings.header,
      body: json.encode(request.toJson()),
    );

    try {
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return GlobalResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }
}
