import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:apimodule/api/config/endpoint.dart';
import 'package:apimodule/api/config/apisettings.dart';
import 'package:apimodule/model/request/global_request.dart';
import 'package:apimodule/model/request/status_vaksinasi_request.dart';
import 'package:apimodule/model/request/vaksinasi_request.dart';
import 'package:apimodule/model/response/global_response.dart';
import 'package:apimodule/model/response/vaksinasi_response.dart';

class VaksinasiService {
  static Future<dynamic> fetchStatusVaksinasi(
      GlobalRequest globalRequest) async {
    var vaksinRequest = new Map<String, dynamic>();
    vaksinRequest['nip_nik'] = globalRequest.nipNik;

    try {
      final response = await http.post(
        EndpointSimpersaa.vaksinGetDataVaksin,
        headers: null,
        body: vaksinRequest,
      );

      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return VaksinasiResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<GlobalResponse> fetchSaveInfoCovid(
      StatusVaksinasiRequest request) async {
    var vaksinRequest = new Map<String, dynamic>();
    vaksinRequest['nip_nik'] = request.nipNik;
    vaksinRequest['p_covid'] = request.pCovid ? "true" : "false";
    vaksinRequest['p_vaksin'] = request.pVaksin ? "true" : "false";

    try {
      final response = await http.post(
        EndpointSimpersaa.vaksinSaveCovid,
        headers: null,
        body: vaksinRequest,
      );

      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return GlobalResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<GlobalResponse> fetchSaveInfoVaksinasi(
      VaksinasiRequest request) async {
    var vaksinRequest = new Map<String, dynamic>();
    vaksinRequest['nip_nik'] = request.nipNik;
    vaksinRequest['vaksin_ke'] = request.vaksinKe;
    vaksinRequest['tanggal_daftar'] = request.tanggalDaftar;
    vaksinRequest['tanggal_vaksin'] = request.tanggalVaksin;
    vaksinRequest['alamat_vaksin'] = request.alamatVaksin;
    vaksinRequest['penyelenggaraan'] = request.penyelenggaraan;

    try {
      final response = await http.post(
        EndpointSimpersaa.vaksinSaveVaksin,
        headers: null,
        body: vaksinRequest,
      );

      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return GlobalResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on TimeoutException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    } on SocketException catch (_) {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }
}
